@@ -45,9 +45,8 @@ import re
 import cmd
 import optparse
 import sys
-import time
 from pprint import pprint
-from datetime import datetime
+from datetime import date
 
 # this is python 2.x style
 def introspect_handler_2(handler):
@@ -620,17 +619,16 @@ class RawCmdln(cmd.Cmd):
         usage:
             ${name} man
         """
-        mandate = datetime.utcfromtimestamp(int(os.environ.get('SOURCE_DATE_EPOCH', time.time())))
-        self.stdout.write(
+        self.stdout.write(bytes(
             self.man_header % {
-                'date': mandate.strftime('%b %Y'),
+                'date': date.today().strftime('%b %Y'),
                 'version': self.get_version(),
                 'name': self.name,
                 'ucname': self.name.upper()
-                }
-            )
+                },
+            "utf-8"))
 
-        self.stdout.write(self.man_commands_header)
+        self.stdout.write(bytes(self.man_commands_header, "utf-8"))
         commands = self._help_get_command_list()
         for command, doc in commands:
             cmdname = command.split(' ')[0]
@@ -641,14 +639,14 @@ class RawCmdln(cmd.Cmd):
                     line = line[8:]
                 lines.append(man_escape(line))
 
-            self.stdout.write(
-                '.TP\n\\fB%s\\fR\n%s\n' % (command, '\n'.join(lines)))
+            self.stdout.write(bytes(
+                '.TP\n\\fB%s\\fR\n%s\n' % (command, '\n'.join(lines)), "utf-8"))
 
-        self.stdout.write(self.man_options_header)
-        self.stdout.write(
-            man_escape(self._help_preprocess('${option_list}', None)))
+        self.stdout.write(bytes(self.man_options_header, "utf-8"))
+        self.stdout.write(bytes(
+            man_escape(self._help_preprocess('${option_list}', None)), "utf-8"))
 
-        self.stdout.write(self.man_footer)
+        self.stdout.write(bytes(self.man_footer, "utf-8"))
 
         self.stdout.flush()
 
@@ -893,7 +891,7 @@ class RawCmdln(cmd.Cmd):
                 warnings.warn("argument '**%s' on '%s.%s' command "
                               "handler will never get values"
                               % (name, self.__class__.__name__,
-                                 getattr(func, "__name__", getattr(func, "func_name"))))
+                                 getattr(func_defaults, "__name__", getattr(func_defaults, "func_name"))))
             if co_flags & CO_FLAGS_ARGS:
                 name = argnames.pop(-1)
                 tail = "[%s...]" % name.upper()
