@@ -7,12 +7,12 @@ from __future__ import print_function
 
 """Read osc configuration and store it in a dictionary
 
-This module reads and parses oscrc. The resulting configuration is stored
+This module reads and parses ~/.oscrc. The resulting configuration is stored
 for later usage in a dictionary named 'config'.
-The oscrc is kept mode 0600, so that it is not publically readable.
+The .oscrc is kept mode 0600, so that it is not publically readable.
 This gives no real security for storing passwords.
 If in doubt, use your favourite keyring.
-Password is stored on ~/.config/osc/oscrc as bz2 compressed and base64 encoded, so that is fairly
+Password is stored on ~/.oscrc as bz2 compressed and base64 encoded, so that is fairly
 large and not to be recognized or remembered easily by an occasional spectator.
 
 If information is missing, it asks the user questions.
@@ -41,9 +41,6 @@ import base64
 import os
 import re
 import sys
-import ssl
-import warnings
-import getpass
 
 try:
     from http.cookiejar import LWPCookieJar, CookieJar
@@ -52,21 +49,19 @@ try:
     from urllib.parse import urlsplit
     from urllib.error import URLError
     from urllib.request import HTTPBasicAuthHandler, HTTPCookieProcessor, HTTPPasswordMgrWithDefaultRealm, ProxyHandler
-    from urllib.request import AbstractHTTPHandler, build_opener, proxy_bypass, HTTPSHandler
+    from urllib.request import AbstractHTTPHandler, build_opener, proxy_bypass
 except ImportError:
     #python 2.x
     from cookielib import LWPCookieJar, CookieJar
     from httplib import HTTPConnection, HTTPResponse
     from StringIO import StringIO
     from urlparse import urlsplit
-    from urllib2 import URLError, HTTPBasicAuthHandler, HTTPCookieProcessor, HTTPPasswordMgrWithDefaultRealm, ProxyHandler, AbstractBasicAuthHandler
-    from urllib2 import AbstractHTTPHandler, build_opener, proxy_bypass, HTTPSHandler
+    from urllib2 import URLError, HTTPBasicAuthHandler, HTTPCookieProcessor, HTTPPasswordMgrWithDefaultRealm, ProxyHandler
+    from urllib2 import AbstractHTTPHandler, build_opener, proxy_bypass
 
 from . import OscConfigParser
 from osc import oscerr
-from osc.util.helper import raw_input
 from .oscsslexcp import NoSecureSSLError
-from osc import credentials
 
 GENERIC_KEYRING = False
 GNOME_KEYRING = False
@@ -78,8 +73,13 @@ except:
     try:
         import gobject
         gobject.set_application_name('osc')
-        import gnomekeyring
-        GNOME_KEYRING = gnomekeyring.is_available()
+        import gnomekeyring #pylint: disable=import-error
+        if os.environ['GNOME_DESKTOP_SESSION_ID']:
+            # otherwise gnome keyring bindings spit out errors, when you have
+            # it installed, but you are not under gnome
+            # (even though hundreds of gnome-keyring daemons got started in parallel)
+            # another option would be to support kwallet here
+            GNOME_KEYRING = gnomekeyring.is_available()
     except:
         pass
 
@@ -95,9 +95,9 @@ def _get_processors():
         return 1
 
 DEFAULTS = {'apiurl': 'https://api.opensuse.org',
-            'user': None,
-            'pass': None,
-            'passx': None,
+            'user': 'your_username',
+            'pass': 'your_password',
+            'passx': '',
             'packagecachedir': '/var/tmp/osbuild-packagecache',
             'su-wrapper': 'sudo',
 
@@ -112,11 +112,10 @@ DEFAULTS = {'apiurl': 'https://api.opensuse.org',
             'build-vmdisk-rootsize': '',        # optional for VM builds
             'build-vmdisk-swapsize': '',        # optional for VM builds
             'build-vmdisk-filesystem': '',        # optional for VM builds
-            'build-vm-user': '',                # optional for VM builds
             'build-kernel': '',                 # optional for VM builds
             'build-initrd': '',                 # optional for VM builds
 
-            'build-jobs': str(_get_processors()),
+            'build-jobs': _get_processors(),
             'builtin_signature_check': '1',     # by default use builtin check for verify pkgs
             'icecream': '0',
 
@@ -127,7 +126,6 @@ DEFAULTS = {'apiurl': 'https://api.opensuse.org',
             'http_full_debug': '0',
             'http_retries': '3',
             'verbose': '1',
-            'no_preinstallimage': '0',
             'traceback': '0',
             'post_mortem': '0',
             'use_keyring': '0',
@@ -149,8 +147,8 @@ DEFAULTS = {'apiurl': 'https://api.opensuse.org',
             'checkout_rooted': '0',
             # local files to ignore with status, addremove, ....
             'exclude_glob': '.osc CVS .svn .* _linkerror *~ #*# *.orig *.bak *.changes.vctmp.*',
-            # whether to keep passwords in plaintext (deprecated (see creds manager)).
-            'plaintext_passwd': '0',
+            # whether to keep passwords in plaintext.
+            'plaintext_passwd': '1',
             # limit the age of requests shown with 'osc req list'.
             # this is a default only, can be overridden by 'osc req list -D NNN'
             # Use 0 for unlimted.
@@ -158,11 +156,10 @@ DEFAULTS = {'apiurl': 'https://api.opensuse.org',
             # check for unversioned/removed files before commit
             'check_filelist': '1',
             # check for pending requests after executing an action (e.g. checkout, update, commit)
-            'check_for_request_on_action': '1',
+            'check_for_request_on_action': '0',
             # what to do with the source package if the submitrequest has been accepted
             'submitrequest_on_accept_action': '',
             'request_show_interactive': '0',
-            'request_show_source_buildstatus': '0',
             # if a review is accepted in interactive mode and a group
             # was specified the review will be accepted for this group
             'review_inherit_group': '0',
@@ -178,30 +175,19 @@ DEFAULTS = {'apiurl': 'https://api.opensuse.org',
             'maintained_update_project_attribute': 'OBS:UpdateProject',
             'show_download_progress': '0',
             # path to the vc script
-            'vc-cmd': '/usr/lib/build/vc',
-
-            # heuristic to speedup Package.status
-            'status_mtime_heuristic': '0'
+            'vc-cmd': '/usr/lib/build/vc'
 }
 
-# some distros like Debian rename and move build to obs-build
-if not os.path.isfile('/usr/bin/build') and os.path.isfile('/usr/bin/obs-build'):
-    DEFAULTS['build-cmd'] = '/usr/bin/obs-build'
-if not os.path.isfile('/usr/lib/build/vc') and os.path.isfile('/usr/lib/obs-build/vc'):
-    DEFAULTS['vc-cmd'] = '/usr/lib/obs-build/vc'
-
 # being global to this module, this dict can be accessed from outside
 # it will hold the parsed configuration
 config = DEFAULTS.copy()
 
 boolean_opts = ['debug', 'do_package_tracking', 'http_debug', 'post_mortem', 'traceback', 'check_filelist', 'plaintext_passwd',
     'checkout_no_colon', 'checkout_rooted', 'check_for_request_on_action', 'linkcontrol', 'show_download_progress', 'request_show_interactive',
-    'request_show_source_buildstatus', 'review_inherit_group', 'use_keyring', 'gnome_keyring', 'no_verify', 'builtin_signature_check',
-    'http_full_debug', 'include_request_from_project', 'local_service_run', 'buildlog_strip_time', 'no_preinstallimage',
-    'status_mtime_heuristic']
-integer_opts = ['build-jobs']
+    'review_inherit_group', 'use_keyring', 'gnome_keyring', 'no_verify', 'builtin_signature_check', 'http_full_debug',
+    'include_request_from_project', 'local_service_run', 'buildlog_strip_time']
 
-api_host_options = ['user', 'pass', 'passx', 'aliases', 'http_headers', 'realname', 'email', 'sslcertck', 'cafile', 'capath', 'trusted_prj']
+api_host_options = ['user', 'pass', 'passx', 'aliases', 'http_headers', 'email', 'sslcertck', 'cafile', 'capath', 'trusted_prj']
 
 new_conf_template = """
 [general]
@@ -278,11 +264,8 @@ apiurl = %(apiurl)s
 # extra packages to install when building packages locally (osc build)
 # this corresponds to osc build's -x option and can be overridden with that
 # -x '' can also be given on the command line to override this setting, or
-# you can have an empty setting here. This global setting may leads to 
-# dependency problems when the base distro is not providing the package.
-# => using server side definition via cli_debug_packages substitute rule is
-#    recommended therefore.
-#extra-pkgs = 
+# you can have an empty setting here.
+#extra-pkgs = vim gdb strace
 
 # build platform is used if the platform argument is omitted to osc build
 #build_repository = %(build_repository)s
@@ -299,6 +282,12 @@ apiurl = %(apiurl)s
 # local files to ignore with status, addremove, ....
 #exclude_glob = %(exclude_glob)s
 
+# keep passwords in plaintext.
+# Set to 0 to obfuscate passwords. It's no real security, just
+# prevents most people from remembering your password if they watch
+# you editing this file.
+#plaintext_passwd = %(plaintext_passwd)s
+
 # limit the age of requests shown with 'osc req list'.
 # this is a default only, can be overridden by 'osc req list -D NNN'
 # Use 0 for unlimted.
@@ -322,11 +311,14 @@ apiurl = %(apiurl)s
 # print call traces in case of errors
 #traceback = 1
 
+# use KDE/Gnome/MacOS/Windows keyring for credentials if available
+#use_keyring = 1
+
 # check for unversioned/removed files before commit
 #check_filelist = 1
 
 # check for pending requests after executing an action (e.g. checkout, update, commit)
-#check_for_request_on_action = 1
+#check_for_request_on_action = 0
 
 # what to do with the source package if the submitrequest has been accepted. If
 # nothing is specified the API default is used
@@ -350,10 +342,10 @@ apiurl = %(apiurl)s
 #review_inherit_group = 1
 
 [%(apiurl)s]
+user = %(user)s
+pass = %(pass)s
 # set aliases for this apiurl
 # aliases = foo, bar
-# real name used in .changes, unless the one from osc meta prj <user> will be used
-# realname =
 # email used in .changes, unless the one from osc meta prj <user> will be used
 # email =
 # additional headers to pass to a request, e.g. for special authentication
@@ -361,6 +353,8 @@ apiurl = %(apiurl)s
 #       User: mumblegack
 # Plain text password
 #pass =
+# Force using of keyring for this API
+#keyring = 1
 """
 
 
@@ -388,18 +382,17 @@ cookiejar = None
 
 def parse_apisrv_url(scheme, apisrv):
     if apisrv.startswith('http://') or apisrv.startswith('https://'):
-        url = apisrv
+        return urlsplit(apisrv)[0:2]
     elif scheme != None:
-        url = scheme + apisrv
+        # the split/join is needed to get a proper url (e.g. without a trailing slash)
+        return urlsplit(urljoin(scheme, apisrv))[0:2]
     else:
         msg = 'invalid apiurl \'%s\' (specify the protocol (http:// or https://))' % apisrv
         raise URLError(msg)
-    scheme, url, path = urlsplit(url)[0:3]
-    return scheme, url, path.rstrip('/')
 
 
-def urljoin(scheme, apisrv, path=''):
-    return '://'.join([scheme, apisrv]) + path
+def urljoin(scheme, apisrv):
+    return '://'.join([scheme, apisrv])
 
 
 def is_known_apiurl(url):
@@ -408,21 +401,6 @@ def is_known_apiurl(url):
     return apiurl in config['api_host_options']
 
 
-def extract_known_apiurl(url):
-    """
-    Return longest prefix of given url that is known apiurl,
-    None if there is no known apiurl that is prefix of given url.
-    """
-    scheme, host, path = parse_apisrv_url(None, url)
-    p = path.split('/')
-    while p:
-        apiurl = urljoin(scheme, host, '/'.join(p))
-        if apiurl in config['api_host_options']:
-            return apiurl
-        p.pop()
-    return None
-
-
 def get_apiurl_api_host_options(apiurl):
     """
     Returns all apihost specific options for the given apiurl, None if
@@ -463,9 +441,10 @@ def get_apiurl_usr(apiurl):
 # So we need to build a new opener everytime we switch the
 # apiurl (because different apiurls may have different
 # cafile/capath locations)
-def _build_opener(apiurl):
+def _build_opener(url):
     from osc.core import __version__
-    global config
+
+    apiurl = urljoin(*parse_apisrv_url(None, url))
     if 'last_opener' not in _build_opener.__dict__:
         _build_opener.last_opener = (None, None)
     if apiurl == _build_opener.last_opener[0]:
@@ -481,33 +460,38 @@ def _build_opener(apiurl):
 
     # workaround for http://bugs.python.org/issue9639
     authhandler_class = HTTPBasicAuthHandler
-    if sys.version_info >= (2, 6, 6) and sys.version_info < (2, 7, 9):
+    if sys.version_info >= (2, 6, 6) and sys.version_info < (2, 7, 1) \
+        and not 'reset_retry_count' in dir(HTTPBasicAuthHandler):
+        print('warning: your urllib2 version seems to be broken. ' \
+            'Using a workaround for http://bugs.python.org/issue9639', file=sys.stderr)
+
         class OscHTTPBasicAuthHandler(HTTPBasicAuthHandler):
-            # The following two functions were backported from upstream 2.7.
-            def http_error_auth_reqed(self, authreq, host, req, headers):
-                authreq = headers.get(authreq, None)
+            def http_error_401(self, *args):
+                response = HTTPBasicAuthHandler.http_error_401(self, *args)
+                self.retried = 0
+                return response
 
-                if authreq:
-                    mo = AbstractBasicAuthHandler.rx.search(authreq)
-                    if mo:
-                        scheme, quote, realm = mo.groups()
-                        if quote not in ['"', "'"]:
-                            warnings.warn("Basic Auth Realm was unquoted",
-                                          UserWarning, 2)
-                        if scheme.lower() == 'basic':
-                            return self.retry_http_basic_auth(host, req, realm)
+            def http_error_404(self, *args):
+                self.retried = 0
+                return None
 
+        authhandler_class = OscHTTPBasicAuthHandler
+    elif sys.version_info >= (2, 6, 6) and sys.version_info < (2, 7, 1):
+        class OscHTTPBasicAuthHandler(HTTPBasicAuthHandler):
+            def http_error_404(self, *args):
+                self.reset_retry_count()
+                return None
+
+        authhandler_class = OscHTTPBasicAuthHandler
+    elif sys.version_info >= (2, 6, 5) and sys.version_info < (2, 6, 6):
+        # workaround for broken urllib2 in python 2.6.5: wrong credentials
+        # lead to an infinite recursion
+        class OscHTTPBasicAuthHandler(HTTPBasicAuthHandler):
             def retry_http_basic_auth(self, host, req, realm):
-                user, pw = self.passwd.find_user_password(realm, host)
-                if pw is not None:
-                    raw = "%s:%s" % (user, pw)
-                    auth = 'Basic %s' % base64.b64encode(raw).strip()
-                    if req.get_header(self.auth_header, None) == auth:
-                        return None
-                    req.add_unredirected_header(self.auth_header, auth)
-                    return self.parent.open(req, timeout=req.timeout)
-                else:
+                # don't retry if auth failed
+                if req.get_header(self.auth_header, None) is not None:
                     return None
+                return HTTPBasicAuthHandler.retry_http_basic_auth(self, host, req, realm)
 
         authhandler_class = OscHTTPBasicAuthHandler
 
@@ -537,27 +521,20 @@ def _build_opener(apiurl):
                     capath = i
                     break
         if not cafile and not capath:
-            raise oscerr.OscIOError(None, 'No CA certificates found. (You may want to install ca-certificates-mozilla package)')
+            raise oscerr.OscIOError(None, 'No CA certificates found')
         ctx = oscssl.mySSLContext()
         if ctx.load_verify_locations(capath=capath, cafile=cafile) != 1:
-            raise oscerr.OscIOError(None, 'No CA certificates found. (You may want to install ca-certificates-mozilla package)')
+            raise oscerr.OscIOError(None, 'No CA certificates found')
         opener = m2urllib2.build_opener(ctx, oscssl.myHTTPSHandler(ssl_context=ctx, appname='osc'), HTTPCookieProcessor(cookiejar), authhandler, proxyhandler)
     else:
-        handlers = [HTTPCookieProcessor(cookiejar), authhandler, proxyhandler]
-        try:
-            # disable ssl cert check in python >= 2.7.9
-            ctx = ssl._create_unverified_context()
-            handlers.append(HTTPSHandler(context=ctx))
-        except AttributeError:
-            pass
         print("WARNING: SSL certificate checks disabled. Connection is insecure!\n", file=sys.stderr)
-        opener = build_opener(*handlers)
+        opener = build_opener(HTTPCookieProcessor(cookiejar), authhandler, proxyhandler)
     opener.addheaders = [('User-agent', 'osc/%s' % __version__)]
     _build_opener.last_opener = (apiurl, opener)
     return opener
 
 
-def init_basicauth(config, config_mtime):
+def init_basicauth(config):
     """initialize urllib2 with the credentials for Basic Authentication"""
 
     def filterhdrs(meth, ishdr, *hdrs):
@@ -610,9 +587,6 @@ def init_basicauth(config, config_mtime):
     cookiejar = LWPCookieJar(cookie_file)
     try:
         cookiejar.load(ignore_discard=True)
-        if int(round(config_mtime)) > int(os.stat(cookie_file).st_mtime):
-            cookiejar.clear()
-            cookiejar.save()
     except IOError:
         try:
             fd = os.open(cookie_file, os.O_CREAT | os.O_WRONLY | os.O_TRUNC, 0o600)
@@ -629,9 +603,7 @@ def get_configParser(conffile=None, force_read=False):
     ConfigParser object is stored in a method attribute and this attribute
     is returned unless you pass force_read=True.
     """
-    if not conffile:
-        conffile = identify_conf()
-
+    conffile = conffile or os.environ.get('OSC_CONFIG', '~/.oscrc')
     conffile = os.path.expanduser(conffile)
     if 'conffile' not in get_configParser.__dict__:
         get_configParser.conffile = conffile
@@ -647,8 +619,6 @@ def write_config(fname, cp):
     if os.path.exists(fname) and not os.path.isfile(fname):
         # only write to a regular file
         return
-    if not os.path.exists(os.path.dirname(fname)):
-        os.makedirs(os.path.dirname(fname), mode=0o700)
     with open(fname + '.new', 'w') as f:
         cp.write(f, comments=True)
     try:
@@ -660,7 +630,7 @@ def write_config(fname, cp):
         raise
 
 
-def config_set_option(section, opt, val=None, delete=False, update=True, creds_mgr_descr=None, **kwargs):
+def config_set_option(section, opt, val=None, delete=False, update=True, **kwargs):
     """
     Sets a config option. If val is not specified the current/default value is
     returned. If val is specified, opt is set to val and the new value is returned.
@@ -674,18 +644,18 @@ def config_set_option(section, opt, val=None, delete=False, update=True, creds_m
     general_opts = [i for i in DEFAULTS.keys() if not i in ['user', 'pass', 'passx']]
     if section != 'general':
         section = config['apiurl_aliases'].get(section, section)
-        scheme, host, path = \
+        scheme, host = \
             parse_apisrv_url(config.get('scheme', 'https'), section)
-        section = urljoin(scheme, host, path)
+        section = urljoin(scheme, host)
 
     sections = {}
     for url in cp.sections():
         if url == 'general':
             sections[url] = url
         else:
-            scheme, host, path = \
+            scheme, host = \
                 parse_apisrv_url(config.get('scheme', 'https'), url)
-            apiurl = urljoin(scheme, host, path)
+            apiurl = urljoin(scheme, host)
             sections[apiurl] = url
 
     section = sections.get(section.rstrip('/'), section)
@@ -696,37 +666,11 @@ def config_set_option(section, opt, val=None, delete=False, update=True, creds_m
         raise oscerr.ConfigError('unknown config option \'%s\'' % opt, config['conffile'])
     run = False
     if val:
-        if opt == 'pass':
-            creds_mgr = _get_credentials_manager(section, cp)
-            user = _extract_user_compat(cp, section, creds_mgr)
-            old_pw = creds_mgr.get_password(section, user, defer=False)
-            try:
-                creds_mgr.delete_password(section, user)
-                if creds_mgr_descr:
-                    creds_mgr_new = creds_mgr_descr.create(cp)
-                else:
-                    creds_mgr_new = creds_mgr
-                creds_mgr_new.set_password(section, user, val)
-                write_config(config['conffile'], cp)
-                opt = credentials.AbstractCredentialsManager.config_entry
-                old_pw = None
-            finally:
-                if old_pw is not None:
-                    creds_mgr.set_password(section, user, old_pw)
-                    # not nice, but needed if the Credentials Manager will change
-                    # something in cp
-                    write_config(config['conffile'], cp)
-        else:
-            cp.set(section, opt, val)
-            write_config(config['conffile'], cp)
+        cp.set(section, opt, val)
+        write_config(config['conffile'], cp)
         run = True
-    elif delete and (cp.has_option(section, opt) or opt == 'pass'):
-        if opt == 'pass':
-            creds_mgr = _get_credentials_manager(section, cp)
-            user = _extract_user_compar(cp, section, creds_mgr)
-            creds_mgr.delete_password(section, user)
-        else:
-            cp.remove_option(section, opt)
+    elif delete and cp.has_option(section, opt):
+        cp.remove_option(section, opt)
         write_config(config['conffile'], cp)
         run = True
     if run and update:
@@ -739,17 +683,15 @@ def config_set_option(section, opt, val=None, delete=False, update=True, creds_m
         return (opt, cp.get(section, opt, raw=True))
     return (opt, None)
 
-def _extract_user_compat(cp, section, creds_mgr):
-    """
-    This extracts the user either from the ConfigParser or
-    the creds_mgr. Only needed for deprecated Gnome Keyring
-    """
-    user = cp.get(section, 'user')
-    if user is None and hasattr(creds_mgr, 'get_user'):
-        user = creds_mgr.get_user(section)
-    return user
+def passx_decode(passx):
+    """decode the obfuscated password back to plain text password"""
+    return bz2.decompress(base64.b64decode(passx.encode("ascii"))).decode("ascii")
 
-def write_initial_config(conffile, entries, custom_template='', creds_mgr_descriptor=None):
+def passx_encode(passwd):
+    """encode plain text password to obfuscated form"""
+    return base64.b64encode(bz2.compress(passwd.encode('ascii'))).decode("ascii")
+
+def write_initial_config(conffile, entries, custom_template=''):
     """
     write osc's intial configuration file. entries is a dict which contains values
     for the config file (e.g. { 'user' : 'username', 'pass' : 'password' } ).
@@ -758,62 +700,72 @@ def write_initial_config(conffile, entries, custom_template='', creds_mgr_descri
     conf_template = custom_template or new_conf_template
     config = DEFAULTS.copy()
     config.update(entries)
+    # at this point use_keyring and gnome_keyring are str objects
+    if config['use_keyring'] == '1' and GENERIC_KEYRING:
+        protocol, host = \
+            parse_apisrv_url(None, config['apiurl'])
+        keyring.set_password(host, config['user'], config['pass'])
+        config['pass'] = ''
+        config['passx'] = ''
+    elif config['gnome_keyring'] == '1' and GNOME_KEYRING:
+        protocol, host = \
+            parse_apisrv_url(None, config['apiurl'])
+        gnomekeyring.set_network_password_sync(
+            user=config['user'],
+            password=config['pass'],
+            protocol=protocol,
+            server=host)
+        config['user'] = ''
+        config['pass'] = ''
+        config['passx'] = ''
+    if not config['plaintext_passwd']:
+        config['pass'] = ''
+    else:
+        config['passx'] = passx_encode(config['pass'])
+
     sio = StringIO(conf_template.strip() % config)
     cp = OscConfigParser.OscConfigParser(DEFAULTS)
     cp.readfp(sio)
-    cp.set(config['apiurl'], 'user', config['user'])
-    if creds_mgr_descriptor:
-        creds_mgr = creds_mgr_descriptor.create(cp)
-    else:
-        creds_mgr = _get_credentials_manager(config['apiurl'], cp)
-    creds_mgr.set_password(config['apiurl'], config['user'], config['pass'])
     write_config(conffile, cp)
 
 
-def add_section(filename, url, user, passwd, creds_mgr_descriptor=None):
+def add_section(filename, url, user, passwd):
     """
     Add a section to config file for new api url.
     """
-    global config
+
     cp = get_configParser(filename)
     try:
         cp.add_section(url)
     except OscConfigParser.configparser.DuplicateSectionError:
         # Section might have existed, but was empty
         pass
-    cp.set(url, 'user', user)
-    if creds_mgr_descriptor:
-        creds_mgr = creds_mgr_descriptor.create(cp)
-    else:
-        creds_mgr = _get_credentials_manager(url, cp)
-    creds_mgr.set_password(url, user, passwd)
-    write_config(filename, cp)
-
-
-def _get_credentials_manager(url, cp):
-    if cp.has_option(url, credentials.AbstractCredentialsManager.config_entry):
-        creds_mgr = credentials.create_credentials_manager(url, cp)
-        if creds_mgr is None:
-            msg = 'Unable to instantiate creds mgr (section: %s)' % url
-            conffile = get_configParser.conffile
-            raise oscerr.ConfigMissingCredentialsError(msg, conffile, url)
-        return creds_mgr
     if config['use_keyring'] and GENERIC_KEYRING:
-        return credentials.get_keyring_credentials_manager(cp)
+        protocol, host = parse_apisrv_url(None, url)
+        keyring.set_password(host, user, passwd)
+        cp.set(url, 'keyring', '1')
+        cp.set(url, 'user', user)
+        cp.remove_option(url, 'pass')
+        cp.remove_option(url, 'passx')
     elif config['gnome_keyring'] and GNOME_KEYRING:
-        protocol, host, path = parse_apisrv_url(None, url)
-        return credentials.GnomeKeyringCredentialsManager(cp, None)
-    elif cp.get(url, 'passx') is not None:
-        return credentials.ObfuscatedConfigFileCredentialsManager(cp, None)
-    return credentials.PlaintextConfigFileCredentialsManager(cp, None)
-
-
-class APIHostOptionsEntry(dict):
-    def __getitem__(self, key, *args, **kwargs):
-        value = super(self.__class__, self).__getitem__(key, *args, **kwargs)
-        if key == 'pass' and callable(value):
-            value = value()
-        return value
+        protocol, host = parse_apisrv_url(None, url)
+        gnomekeyring.set_network_password_sync(
+            user=user,
+            password=passwd,
+            protocol=protocol,
+            server=host)
+        cp.set(url, 'keyring', '1')
+        cp.remove_option(url, 'pass')
+        cp.remove_option(url, 'passx')
+    else:
+        cp.set(url, 'user', user)
+        if not config['plaintext_passwd']:
+            cp.remove_option(url, 'pass')
+            cp.set(url, 'passx', passx_encode(passwd))
+        else:
+            cp.remove_option(url, 'passx')
+            cp.set(url, 'pass', passwd)
+    write_config(filename, cp)
 
 
 def get_config(override_conffile=None,
@@ -829,17 +781,14 @@ def get_config(override_conffile=None,
     """do the actual work (see module documentation)"""
     global config
 
-    if not override_conffile:
-        conffile = identify_conf()
-    else:
-        conffile = override_conffile
-
+    conffile = override_conffile or os.environ.get('OSC_CONFIG', '~/.oscrc')
     conffile = os.path.expanduser(conffile)
+
     if not os.path.exists(conffile):
         raise oscerr.NoConfigfile(conffile, \
                                   account_not_configured_text % conffile)
 
-    # okay, we made sure that oscrc exists
+    # okay, we made sure that .oscrc exists
 
     # make sure it is not world readable, it may contain a password.
     os.chmod(conffile, 0o600)
@@ -855,14 +804,11 @@ def get_config(override_conffile=None,
     config = dict(cp.items('general', raw=1))
     config['conffile'] = conffile
 
-    typed_opts = ((boolean_opts, cp.getboolean), (integer_opts, cp.getint))
-    for opts, meth in typed_opts:
-        for opt in opts:
-            try:
-                config[opt] = meth('general', opt)
-            except ValueError as e:
-                msg = 'cannot parse \'%s\' setting: %s' % (opt, str(e))
-                raise oscerr.ConfigError(msg, conffile)
+    for i in boolean_opts:
+        try:
+            config[i] = cp.getboolean('general', i)
+        except ValueError as e:
+            raise oscerr.ConfigError('cannot parse \'%s\' setting: ' % i + str(e), conffile)
 
     config['packagecachedir'] = os.path.expanduser(config['packagecachedir'])
     config['exclude_glob'] = config['exclude_glob'].split()
@@ -890,18 +836,76 @@ def get_config(override_conffile=None,
     aliases = {}
     for url in [x for x in cp.sections() if x != 'general']:
         # backward compatiblity
-        scheme, host, path = parse_apisrv_url(config.get('scheme', 'https'), url)
-        apiurl = urljoin(scheme, host, path)
-        creds_mgr = _get_credentials_manager(url, cp)
-        # if the deprecated gnomekeyring is used we should use the apiurl instead of url
-        # (that's what the old code did), but this makes things more complex
-        # (also, it is very unlikely that url and apiurl differ)
-        user = _extract_user_compat(cp, url, creds_mgr)
+        scheme, host = parse_apisrv_url(config.get('scheme', 'https'), url)
+        apiurl = urljoin(scheme, host)
+        user = None
+        password = None
+        if config['use_keyring'] and GENERIC_KEYRING:
+            try:
+                # Read from keyring lib if available
+                user = cp.get(url, 'user', raw=True)
+                password = str(keyring.get_password(host, user))
+            except:
+                # Fallback to file based auth.
+                pass
+        elif config['gnome_keyring'] and GNOME_KEYRING:
+            # Read from gnome keyring if available
+            try:
+                gk_data = gnomekeyring.find_network_password_sync(protocol=scheme, server=host)
+                if not 'user' in gk_data[0]:
+                    raise oscerr.ConfigError('no user found in keyring', conffile)
+                user = gk_data[0]['user']
+                if 'password' in gk_data[0]:
+                    password = str(gk_data[0]['password'])
+                else:
+                    # this is most likely an error
+                    print('warning: no password found in keyring', file=sys.stderr)
+            except gnomekeyring.NoMatchError:
+                # Fallback to file based auth.
+                pass
+
+        if not user is None and len(user) == 0:
+            user = None
+            print('Warning: blank user in the keyring for the ' \
+                'apiurl %s.\nPlease fix your keyring entry.', file=sys.stderr)
+
+        if user is not None and password is None:
+            err = ('no password defined for "%s".\nPlease fix your keyring '
+                   'entry or gnome-keyring setup.\nAssuming an empty password.'
+                   % url)
+            print(err, file=sys.stderr)
+            password = ''
+
+        # Read credentials from config
         if user is None:
-            raise oscerr.ConfigMissingCredentialsError('No user found in section %s' % url, conffile, url)
-        password = creds_mgr.get_password(url, user)
-        if password is None:
-            raise oscerr.ConfigMissingCredentialsError('No password found in section %s' % url, conffile, url)
+            #FIXME: this could actually be the ideal spot to take defaults
+            #from the general section.
+            user = cp.get(url, 'user', raw=True)        # need to set raw to prevent '%' expansion
+            password = cp.get(url, 'pass', raw=True)    # especially on password!
+            try:
+                passwordx = passx_decode(cp.get(url, 'passx', raw=True))  # especially on password!
+            except:
+                passwordx = ''
+
+            if password == None or password == 'your_password':
+                password = ''
+
+            if user is None or user == '':
+                raise oscerr.ConfigError('user is blank for %s, please delete or complete the "user=" entry in %s.' % (apiurl, config['conffile']), config['conffile'])
+
+            if config['plaintext_passwd'] and passwordx or not config['plaintext_passwd'] and password:
+                if config['plaintext_passwd']:
+                    if password != passwordx:
+                        print('%s: rewriting from encoded pass to plain pass' % url, file=sys.stderr)
+                    add_section(conffile, url, user, passwordx)
+                    password = passwordx
+                else:
+                    if password != passwordx:
+                        print('%s: rewriting from plain pass to encoded pass' % url, file=sys.stderr)
+                    add_section(conffile, url, user, password)
+
+            if not config['plaintext_passwd']:
+                password = passwordx
 
         if cp.has_option(url, 'http_headers'):
             http_headers = cp.get(url, 'http_headers')
@@ -918,12 +922,11 @@ def get_config(override_conffile=None,
                     raise oscerr.ConfigError(msg, conffile)
                 aliases[key] = url
 
-        entry = {'user': user,
-                 'pass': password,
-                 'http_headers': http_headers}
-        api_host_options[apiurl] = APIHostOptionsEntry(entry)
+        api_host_options[apiurl] = {'user': user,
+                                    'pass': password,
+                                    'http_headers': http_headers}
 
-        optional = ('realname', 'email', 'sslcertck', 'cafile', 'capath')
+        optional = ('email', 'sslcertck', 'cafile', 'capath')
         for key in optional:
             if cp.has_option(url, key):
                 if key == 'sslcertck':
@@ -957,13 +960,11 @@ def get_config(override_conffile=None,
         scheme = config.get('scheme', 'https')
         config['apiurl'] = urljoin(scheme, apisrv)
     if 'apisrc' in config or 'scheme' in config:
-        print('Warning: Use of the \'scheme\' or \'apisrv\' in oscrc is deprecated!\n' \
+        print('Warning: Use of the \'scheme\' or \'apisrv\' in ~/.oscrc is deprecated!\n' \
                             'Warning: See README for migration details.', file=sys.stderr)
     if 'build_platform' in config:
         print('Warning: Use of \'build_platform\' config option is deprecated! (use \'build_repository\' instead)', file=sys.stderr)
         config['build_repository'] = config['build_platform']
-    if config['plaintext_passwd']:
-        print('The \'plaintext_passwd\' option is deprecated and will be ignored', file=sys.stderr)
 
     config['verbose'] = int(config['verbose'])
     # override values which we were called with
@@ -997,43 +998,7 @@ def get_config(override_conffile=None,
         raise e
 
     # finally, initialize urllib2 for to use the credentials for Basic Authentication
-    init_basicauth(config, os.stat(conffile).st_mtime)
+    init_basicauth(config)
 
-def identify_conf():
-    # needed for compat reasons(users may have their oscrc still in ~
-    if 'OSC_CONFIG' in os.environ:
-        return os.environ.get('OSC_CONFIG')
-    if os.path.exists(os.path.expanduser('~/.oscrc')):
-        conffile = '~/.oscrc'
-    else:
-        conffile = os.environ.get('XDG_CONFIG_HOME', '~/.config') + '/osc/oscrc'
-
-    return conffile
-
-def interactive_config_setup(conffile, apiurl, initial=True):
-    user = raw_input('Username: ')
-    passwd = getpass.getpass()
-    creds_mgr_descr = select_credentials_manager_descr()
-    if initial:
-        config = {'user': user, 'pass': passwd}
-        if apiurl:
-            config['apiurl'] = apiurl
-        write_initial_config(conffile, config, creds_mgr_descriptor=creds_mgr_descr)
-    else:
-        add_section(conffile, apiurl, user, passwd, creds_mgr_descriptor=creds_mgr_descr)
-
-def select_credentials_manager_descr():
-    if not credentials.has_keyring_support():
-        print('To use keyrings please install python-keyring.')
-    creds_mgr_descriptors = credentials.get_credentials_manager_descriptors()
-    for i, creds_mgr_descr in enumerate(creds_mgr_descriptors, 1):
-        print('%d) %s (%s)' % (i, creds_mgr_descr.name(), creds_mgr_descr.description()))#
-    i = raw_input('Select credentials manager: ')
-    if not i.isdigit():
-        sys.exit('Invalid selection')
-    i = int(i) - 1
-    if i < 0 or i >= len(creds_mgr_descriptors):
-        sys.exit('Invalid selection')
-    return creds_mgr_descriptors[i]
 
 # vim: sw=4 et
