@@ -82,9 +82,9 @@ class Fetcher:
                         raise oscerr.APIError('CPIO archive is incomplete '
                                               '(see .errors file)')
                     if package == '_repository':
-                        n = re.sub(b'\.pkg\.tar\..z$', b'.arch', hdr.filename)
+                        n = re.sub(b'\.pkg\.tar\.(zst|.z)$', b'.arch', hdr.filename)
                         if n.startswith(b'container:'):
-                            n = re.sub(b'\.tar\..z$', b'.tar', hdr.filename)
+                            n = re.sub(b'\.tar\.(zst|.z)$', b'.tar', hdr.filename)
                             pac = pkgs[decode_it(n.rsplit(b'.', 1)[0])]
                             pac.canonname = hdr.filename
                         else:
