@@ -20,8 +20,12 @@ import re
 import sys
 import stat
 
-from io import BytesIO
-
+#XXX: python 2.7 contains io.StringIO, which needs unicode instead of str
+#therefor try to import old stuff before new one here
+try:
+    from StringIO import StringIO
+except ImportError:
+    from io import StringIO
 
 # workaround for python24
 if not hasattr(os, 'SEEK_SET'):
@@ -44,9 +48,6 @@ class ArHdr:
         self.date = date.strip()
         self.uid = uid.strip()
         self.gid = gid.strip()
-        if not mode.strip():
-            # provide a dummy mode for the ext_fn hdr
-            mode = '0'
         self.mode = stat.S_IMODE(int(mode, 8))
         self.size = int(size)
         self.fmag = fmag
@@ -56,10 +57,10 @@ class ArHdr:
     def __str__(self):
         return '%16s %d' % (self.file, self.size)
 
-class ArFile(BytesIO):
+class ArFile(StringIO):
     """Represents a file which resides in the archive"""
     def __init__(self, fn, uid, gid, mode, buf):
-        BytesIO.__init__(self, buf)
+        StringIO.__init__(self, buf)
         self.name = fn
         self.uid = uid
         self.gid = gid
@@ -74,8 +75,9 @@ class ArFile(BytesIO):
         if not dir:
             dir = os.getcwd()
         fn = os.path.join(dir, self.name)
-        with open(fn, 'wb') as f:
-            f.write(self.getvalue())
+        f = open(fn, 'wb')
+        f.write(self.getvalue())
+        f.close()
         os.chmod(fn, self.mode)
         uid = self.uid
         if uid != os.geteuid() or os.geteuid() != 0:
@@ -95,12 +97,11 @@ class Ar:
     Readonly access.
     """
     hdr_len = 60
-    hdr_pat = re.compile(b'^(.{16})(.{12})(.{6})(.{6})(.{8})(.{10})(.{2})',
-                         re.DOTALL)
+    hdr_pat = re.compile('^(.{16})(.{12})(.{6})(.{6})(.{8})(.{10})(.{2})', re.DOTALL)
 
     def __init__(self, fn = None, fh = None):
         if fn == None and fh == None:
-            raise ValueError('either \'fn\' or \'fh\' must be != None')
+            raise ArError(fn,'either \'fn\' or \'fh\' must be != None')
         if fh != None:
             self.__file = fh
             self.__closefile = False
@@ -122,7 +123,7 @@ class Ar:
 
     def _appendHdr(self, hdr):
         # GNU uses an internal '//' file to store very long filenames
-        if hdr.file.startswith(b'//'):
+        if hdr.file.startswith('//'):
             self.ext_fnhdr = hdr
         else:
             self.hdrs.append(hdr)
@@ -136,11 +137,11 @@ class Ar:
         Another special file is the '/' which contains the symbol lookup table.
         """
         for h in self.hdrs:
-            if h.file == b'/':
+            if h.file == '/':
                 continue
             # remove slashes which are appended by ar
-            h.file = h.file.rstrip(b'/')
-            if not h.file.startswith(b'/'):
+            h.file = h.file.rstrip('/')
+            if not h.file.startswith('/'):
                 continue
             # handle long filename
             off = int(h.file[1:len(h.file)])
@@ -149,11 +150,11 @@ class Ar:
             # XXX: is it safe to read all the data in one chunk? I assume the '//' data section
             #      won't be too large
             data = self.__file.read(self.ext_fnhdr.size)
-            end = data.find(b'/')
+            end = data.find('/')
             if end != -1:
                 h.file = data[0:end]
             else:
-                raise ArError(b'//', 'invalid data section - trailing slash (off: %d)' % start)
+                raise ArError('//', 'invalid data section - trailing slash (off: %d)' % start)
 
     def _get_file(self, hdr):
         self.__file.seek(hdr.dataoff, os.SEEK_SET)
@@ -161,14 +162,25 @@ class Ar:
                       self.__file.read(hdr.size))
 
     def read(self):
-        """reads in the archive."""
+        """reads in the archive. It tries to use mmap due to performance reasons (in case of large files)"""
         if not self.__file:
+            import mmap
             self.__file = open(self.filename, 'rb')
+            try:
+                if sys.platform[:3] != 'win':
+                    self.__file = mmap.mmap(self.__file.fileno(), os.path.getsize(self.__file.name), prot=mmap.PROT_READ)
+                else:
+                    self.__file = mmap.mmap(self.__file.fileno(), os.path.getsize(self.__file.name))
+            except EnvironmentError as e:
+                if e.errno == 19 or ( hasattr(e, 'winerror') and e.winerror == 5 ):
+                    print('cannot use mmap to read the file, falling back to the default io', file=sys.stderr)
+                else:
+                    raise e
         else:
             self.__file.seek(0, os.SEEK_SET)
         self._init_datastructs()
         data = self.__file.read(7)
-        if data != b'!<arch>':
+        if data != '!<arch>':
             raise ArError(self.filename, 'no ar archive')
         pos = 8
         while (len(data) != 0):
@@ -196,19 +208,7 @@ class Ar:
 
     def __iter__(self):
         for h in self.hdrs:
-            if h.file == b'/':
+            if h.file == '/':
                 continue
             yield self._get_file(h)
-
-
-if __name__ == '__main__':
-    if len(sys.argv) != 2:
-        print('usage: %s <arfile>' % sys.argv[0])
-        sys.exit(1)
-    # a potential user might want to pass a bytes instead of a str
-    # to make sure that the ArError's file attribute is always a
-    # bytes
-    ar = Ar(fn=sys.argv[1])
-    ar.read()
-    for hdr in ar.hdrs:
-        print(hdr)
+        raise StopIteration()
