@@ -17,8 +17,8 @@ try:
     from urlparse import urlparse, parse_qs
 except ImportError:
     from io import StringIO
-    from urllib.request import HTTPHandler, addinfourl, build_opener
-    from urllib.parse import urlparse, parse_qs
+    from urllib.request import HTTPHandler, addinfourl, build_opener #pylint: disable=no-name-in-module,import-error
+    from urllib.parse import urlparse, parse_qs #pylint: disable=no-name-in-module,import-error
 
 def urlcompare(url, *args):
     """compare all components of url except query string - it is converted to
@@ -92,12 +92,8 @@ class MyHTTPHandler(HTTPHandler):
         elif exp is None:
             raise RuntimeError('exp or expfile required')
         if exp is not None:
-            # use req.data instead of req.get_data() for python3 compatiblity
-            data = req.data
-            if hasattr(data, 'read'):
-                data = data.read()
-            if data != bytes(exp, "utf-8"):
-                raise RequestDataMismatch(req.get_full_url(), repr(data), repr(exp))
+            if req.get_data() != bytes(exp, "utf-8"):
+                raise RequestDataMismatch(req.get_full_url(), repr(req.get_data()), repr(exp))
         return self.__get_response(req.get_full_url(), **kwargs)
 
     def __get_response(self, url, **kwargs):
@@ -139,7 +135,7 @@ def DELETE(fullurl, **kwargs):
     return urldecorator('DELETE', fullurl, **kwargs)
 
 def addExpectedRequest(method, url, **kwargs):
-    global EXPECTED_REQUESTS
+
     EXPECTED_REQUESTS.append((method, url, kwargs))
 
 class OscTestCase(unittest.TestCase):
