@@ -2,7 +2,9 @@ import osc.core
 import osc.oscerr
 import os
 from common import GET, OscTestCase
-FIXTURES_DIR = os.path.join(os.getcwd(), 'init_project_fixtures')
+
+#FIXTURES_DIR = os.path.join(os.getcwd(), 'init_project_fixtures')
+FIXTURES_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'init_project_fixtures')
 
 def suite():
     import unittest
