@@ -3,7 +3,8 @@ import osc.oscerr
 import os
 from common import OscTestCase
 
-FIXTURES_DIR = os.path.join(os.getcwd(), 'revertfile_fixtures')
+#FIXTURES_DIR = os.path.join(os.getcwd(), 'revertfile_fixtures')
+FIXTURES_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'revertfile_fixtures')
 
 def suite():
     import unittest
