@@ -3,7 +3,9 @@ import osc.oscerr
 import os
 import sys
 from common import GET, OscTestCase
-FIXTURES_DIR = os.path.join(os.getcwd(), 'update_fixtures')
+
+#FIXTURES_DIR = os.path.join(os.path.dirname(os.getcwd(), 'update_fixtures')
+FIXTURES_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'update_fixtures')
 
 def suite():
     import unittest
